sqfunction

Attribute Macro sqfunction 

#[sqfunction]
proc marco for generating compatible functions with the sqvm.

abstractions

the macro uses arguments types and return types to tranlates them into a sqfunction deffintion GetFromSquirrelVm and PushToSquirrelVm define logic for how

attributes

  • VM

    Indicates for which the sqfunction is created .The default is Client

  • ExportName

    Specifies the name for the function on the sqvm

  • ReturnOverwrite

    Overwrites the return type for the sqfunction definition Useful for ensuring type safety for custom structs and other custom types since they default to var.

Traits

this macro heavily relies on traits from rrplug and only exists to generate a parsing code.

refer to the traits for more info